#!/bin/bash

# standard P2J interactive client startup script

# defaults
srcname=$0
cfgdir=${srcname%/*}
up="../../../.."
debug=0
suspend="n"
prog="java"
dump="-XX:+HeapDumpOnOutOfMemoryError"
#dump="-XX:+HeapDumpOnOutOfMemoryError -XX:OnOutOfMemoryError='./stack_dump.sh %p'"
swing="client:driver:type=swing_chui_frame client:chui:rows=24 client:chui:columns=80 client:chui:background=0x000000 client:chui:foreground=0xFFA500 client:chui:selection=0x0000FF client:chui:fontname=monospaced client:chui:fontsize=12"
host="net:server:host=localhost"
cfg=""
logdir=$P2J_LOG_DIR
log=""
srvr=""
test="n"
codepath=""
instance=0

# help text
usage[0]="\nUsage: $0 [-dport] [-s] [-t] [-llogfile] [-ccfgfile] [-iinstance] [-2] [-zcodepath]\n"
usage[1]="Where:\n"
usage[2]="d \t= enable JVM debug mode, use the specified TCP port"
usage[3]="s \t= in JVM debug mode enable, suspend the JVM on startup (does not suspend by default)"
usage[4]="t \t= test mode (displays the command but doesn't execute)"
usage[5]="l \t= log file name in your home dir (all STDERR is redirected to this file, defaults to stderr.log)"
usage[6]="h \t= hostname or IP address for the server (defaults to localhost)"
usage[7]="i \t= server instance number (0..9, assigns the P2J server port, defaults to 0) to which to connect"
usage[8]="c \t= config file name (P2J bootstrap config file name, defaults to standard_client.xml)"
usage[9]="2 \t= enable C2 HotSpot compiler (server compiler for the JVM)"
usage[10]="z \t= specify the path (with no trailing slash) to the location of the p2j.jar, libTerminal.so and libp2j.so"

# process options
while getopts ":d:stu2z:l:h:c:" opt; do
   case $opt in
      d  ) debug=$OPTARG ;;
      s  ) suspend="y" ;;
      t  ) prog="echo "$prog ; test="y" ;;
      l  ) log=$OPTARG ;;
      h  ) host="net:server:host="$OPTARG ;;
      i  ) instance=$OPTARG ;;
      c  ) cfg=$OPTARG ;; 
      2  ) srvr="-server" ;;
      u  ) up=$up"/"$up ;;
      z  ) codepath=$OPTARG ;;
      \? ) for i in "${usage[@]}"; do
              echo -e $i
           done
           exit 1 ;;
   esac
done
shift $(($OPTIND - 1))

# final arg prep
port="net:server:insecure_port="$((3333 + $instance))

if [ $debug -ne 0 ]; then
   dtxt="-Xdebug -Xnoagent -Djava.compiler=NONE -Xrunjdwp:transport=dt_socket,address=$debug,server=y,suspend=$suspend" 
else
   dtxt=""
fi

if [ $log"." == "." ]; then
   if [ $logdir"." == "." ]; then
      logdir="."
   fi
   log="${logdir}/client_$(whoami)_${$}.log"
fi   

if [ $codepath"." == "." ]; then
   codepath="$cfgdir/$up/_p2j/build/lib"
fi   


cfg="$cfgdir/$cfg"
lpath="-Djava.library.path=$codepath/"
cpath="-classpath $codepath/p2j.jar"

# run the P2J client
cmd="exec $prog $srvr $dump $dtxt $lpath $cpath com.goldencode.p2j.main.ClientDriver $host $port $swing"
if [ "$test" == "y" ]; then
   $cmd
else
   $cmd 2>$log
fi

